@@ -18,7 +18,7 @@
 
 __author__ = """Francisco Fernandez"""
 __email__ = "fernandezfrancisco2195@gmail.com"
-__version__ = "0.4.6"
+__version__ = "0.5.0"
 
 
 # ============================================================================
@@ -47,6 +47,6 @@ from .statistics import BlockAverage  # noqa
 
 # io
 from .io import *  # noqa
-from .io.reader import XYZ, LAMMPS, read_log_lammps  # noqa
-from .io.writer import XYZ, LAMMPS, in_lammps  # noqa
+from .io.reader import read_xyz, read_lammpstrj, read_log_lammps  # noqa
+from .io.writer import write_xyz, write_lammpstrj, write_in_lammps  # noqa
 from .io.positions import Positions, spherical_nanoparticle, replicate  # noqa
